netapp_ontap.resources.effective_permission API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.effective_permission`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

This API displays the effective permission granted to a Windows or UNIX user on the specified file or folder path. A path within the FlexCache volume is not supported.

## Examples

### Retrieving the effective permission for the specified Windows user on the specified path of an SVM.

```

# The API:

curl -X GET "https://10.63.26.252/api/protocols/file-security/effective-permissions/cf5f271a-1beb-11ea-8fad-005056bb645e/administrator/windows/%2F?share.name=sh1&return_records=true" -H "accept: application/json" -H "authorization: Basic "

# The response:

{ "svm": { "uuid": "cf5f271a-1beb-11ea-8fad-005056bb645e", "name": "vs1" }, "user": "administrator", "type": "windows", "path": "/", "share": { "path": "/" }, "file_permission": [ "read", "write", "append", "read_ea", "write_ea", "execute", "delete_child", "read_attributes", "write_attributes", "delete", "read_control", "write_dac", "write_owner", "synchronize", "system_security" ], "share_permission": [ "read", "read_ea", "execute", "read_attributes", "read_control", "synchronize" ] }

## Classes

`class EffectivePermission (*args, **kwargs)`

  Displays the effective permission granted to a Windows or UNIX user on the specified file or folder path.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves effective security permissions on a file.

    ### Related ONTAP commands

    - `vserver security file-directory show-effective-permissions`

    ### Learn more

    - `DOC /protocols/file-security/effective-permissions/{svm.uuid}/{path}`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class EffectivePermissionSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the EffectivePermission object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `file_permissions: List[str] GET POST PATCH`

    Specifies the effective permission granted to a user on the specified file or folder path.

  `path: str GET POST PATCH`

    Specifies the path of the file or the folder for which you want to display effective permissions. The path is relative to the SVM root volume. If "-share-name" is specified then path will be relative to the share path.

    Example: /dir1/dir2

  `share: Share GET POST PATCH`

    The share field of the effective_permission.

  `share_permissions: List[str] GET POST PATCH`

    Specifies the effective permission granted to a user on the specified file or folder path.

  `svm: Svm GET POST PATCH`

    The svm field of the effective_permission.

  `type: str GET POST PATCH`

    Specifies the user type. The following values are allowed:

    - windows - Windows user
    - unix - UNIX user

    Valid choices:

    - windows
    - unix
  `user: str GET POST PATCH`

    Specifies the user for which effective permission needs to be displayed for the specified path.

    Example: cifs1/administrator